netapp_ontap.models.vdisk_space_snapshot API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.vdisk_space_snapshot`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VdiskSpaceSnapshotSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VdiskSpaceSnapshot object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `autodelete: VdiskSpaceSnapshotAutodelete GET POST PATCH`

    The autodelete field of the vdisk_space_snapshot.

  `reserve_available: Size GET`

    Size available for snapshots within the snapshot reserve, in bytes.

  `reserve_percent: Size GET POST PATCH`

    The space that has been reserved for snapshot usage, in percent.

  `reserve_size: Size GET`

    Size that has been reserved for snapshot usage, in bytes.

  `space_used_percent: Size GET`

    Percentage of snapshot reserve size that has been used.

  `used: Size GET`

    The total space used by snapshots, in bytes.